@@ -20,6 +20,11 @@
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
+#' @param wls.target numeric vector indicating the spectral quantity values for
+#'   which wavelengths are to be searched and interpolated if need. The
+#'   \code{character} strings "half.maximum" and "half.range" are also accepted
+#'   as arguments. A list with \code{numeric} and/or \code{character} values is
+#'   also accepted.
 #' @param annotations a character vector.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
@@ -43,6 +48,7 @@ raw_plot <- function(spct,
                      pc.out,
                      label.qty,
                      span,
+                     wls.target,
                      annotations,
                      norm,
                      text.size,
@@ -126,11 +132,13 @@ raw_plot <- function(spct,
   }
 
   if (num.counts.cols > 1L) {
+    # remove raw_spct class before melting as it invalidates expectations
+    rmDerivedSpct(spct)
     spct <- tidyr::gather_(data = spct,
                            key_col = "scan",
                            value_col = "counts",
                            gather_cols = counts.cols)
-    setRawSpct(spct, multiple.wl = length(counts.cols))
+    setRawSpct(spct, multiple.wl = num.counts.cols)
     plot <- ggplot(spct) + aes_(x = ~w.length, y = ~counts, linetype = ~scan)
   } else {
     plot <- ggplot(spct) + aes_(x = ~w.length, y = ~counts)
@@ -187,6 +195,7 @@ raw_plot <- function(spct,
                             annotations = annotations,
                             label.qty = label.qty,
                             span = span,
+                            wls.target = wls.target,
                             summary.label = counts.label,
                             text.size = text.size,
                             na.rm = TRUE)
@@ -229,6 +238,11 @@ raw_plot <- function(spct,
 #' @param span a peak is defined as an element in a sequence which is greater
 #'   than all other elements within a window of width span centered at that
 #'   element.
+#' @param wls.target numeric vector indicating the spectral quantity values for
+#'   which wavelengths are to be searched and interpolated if need. The
+#'   \code{character} strings "half.maximum" and "half.range" are also accepted
+#'   as arguments. A list with \code{numeric} and/or \code{character} values is
+#'   also accepted.
 #' @param annotations a character vector ("summaries" is ignored).
 #' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
 #' @param tz character Time zone to use for title and/or subtitle.
@@ -261,6 +275,7 @@ autoplot.raw_spct <-
            pc.out = FALSE,
            label.qty = "mean",
            span = NULL,
+           wls.target = "HM",
            annotations = NULL,
            time.format = "",
            tz = "UTC",
@@ -282,7 +297,7 @@ autoplot.raw_spct <-
       } else if (is.waveband(range)) {
         w.band <- range
       } else {
-        w.band <-  waveband(range, wb.name = "Total")
+        w.band <- waveband(range, wb.name = "Total")
       }
     }
 
@@ -291,6 +306,7 @@ autoplot.raw_spct <-
              range = range,
              label.qty = label.qty,
              span = span,
+             wls.target = wls.target,
              pc.out = pc.out,
              annotations = annotations,
              norm = norm,
@@ -300,10 +316,10 @@ autoplot.raw_spct <-
              na.rm = na.rm,
              ...) +
       autotitle(object = object,
-                   time.format = time.format,
-                   tz = tz,
-                   object.label = object.label,
-                   annotations = annotations)
+                time.format = time.format,
+                tz = tz,
+                object.label = object.label,
+                annotations = annotations)
   }
 
 
