@@ -31,6 +31,8 @@
 #' @param integral.fun function on $x$ and $y$.
 #' @param label.mult numeric Scaling factor applied to y-integral values before
 #'   conversion into character strings.
+#' @param chroma.type character one of "CMF" (color matching function) or "CC"
+#'   (color coordinates) or a \code{\link[photobiology]{chroma_spct}} object.
 #' @param label.fmt character string giving a format definition for converting
 #'   y-integral values into character strings by means of function
 #'   \code{\link{sprintf}}.
@@ -105,6 +107,7 @@ stat_wb_total <- function(mapping = NULL, data = NULL, geom = "text",
                        w.band = NULL,
                        integral.fun = integrate_xy,
                        label.mult = 1,
+                       chroma.type = "CMF",
                        label.fmt = "%.3g",
                        ypos.mult = 1.07,
                        ypos.fixed = NULL,
@@ -116,6 +119,7 @@ stat_wb_total <- function(mapping = NULL, data = NULL, geom = "text",
     params = list(w.band = w.band,
                   integral.fun = integral.fun,
                   label.mult = label.mult,
+                  chroma.type = chroma.type,
                   label.fmt = label.fmt,
                   ypos.mult = ypos.mult,
                   ypos.fixed = ypos.fixed,
@@ -135,6 +139,7 @@ StatWbTotal <-
                                             w.band,
                                             integral.fun,
                                             label.mult,
+                                            chroma.type,
                                             label.fmt,
                                             ypos.mult,
                                             ypos.fixed) {
@@ -176,9 +181,9 @@ StatWbTotal <-
                                                     wb.ymax = max(data[["y"]]),
                                                     wb.yint = yint.tmp,
                                                     wb.ymean = ymean.tmp,
-                                                    wb.color = color_of(wb),
+                                                    wb.color = color_of(wb, chroma.type = chroma.type),
                                                     wb.name = labels(wb)[["label"]],
-                                                    BW.color = black_or_white(color_of(wb)))
+                                                    BW.color = black_or_white(color_of(wb, chroma.type = chroma.type)))
                                          )
                      }
                      if (is.null(ypos.fixed)) {
